package com.xy.service;

import com.xy.annotate.RestMappingController;
import com.xy.dto.TranslateDto;
import com.xy.translate.baidu.TransApi;
import com.xy.utils.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

/**
 * 字典翻译服务
 */
@Api(tags = "字典翻译服务")
@Slf4j
@Service
@RequiredArgsConstructor
@RestMappingController("/translate_dict")
public class SysDictTranslateService {

    private final SysDictServiceImpl sysDictService;

    @PostMapping("/one")
    @ApiOperation("单个翻译-同步返回结果")
    public R<String> translateOne(@RequestBody @Validated TranslateDto.One one) {
        String content = one.getContent();
        String targetType = one.getTargetType();
        String translatedValue = TransApi.translate(content, "zh", targetType);
        return R.ok(translatedValue);
    }


    /**
     * 全量翻译
     *
     * @return
     */
    @PostMapping("/all")
    @ApiOperation("全量翻译-已翻译的忽略")
    public R<?> translateAll() {
        sysDictService.translateAllDict();
        return R.ok();
    }


    @PostMapping("/refreshAll")
    @ApiOperation("全量刷新redis缓存")
    public R<?> refreshAll() {
        sysDictService.refreshAll();
        return R.ok();
    }


}
